@@ -278,6 +278,31 @@ def translate(to_translate, to_language="auto", from_language="auto"):
         return ("")
 
 
+def getUrlData(url, timeout=10, try_times = 5):
+    header = {'User-Agent': random.choice(USER_AGENTS)}    
+    while try_times >-1:
+        try:
+            req = urllib.request.Request(url=url, headers=header, method='GET')
+            htmlcode = urllib.request.urlopen(req, timeout=timeout)#.read()
+            content = htmlcode.read().decode('utf-8',errors='ignore')
+            return content
+        except Exception as e:
+            try_times-=1
+            if try_times==4:
+                time.sleep(10)
+            if try_times==3:
+                time.sleep(20)
+            if try_times==2:
+                time.sleep(30)
+            if try_times==1:
+                time.sleep(40)
+            if try_times==0:
+                time.sleep(60)
+            time.sleep(0.1)
+            if try_times == 0:
+                raise e
+
+
 class Sorted_dict(object):
     def __init__(self, seq=None, keyfunc=lambda v: v, valfunc=lambda v: v, ascending=True):
         super().__init__()
